import { TextField } from "@material-ui/core";
import React from "react";
import { Field } from "redux-form";
import classes from "./FormControls.module.css";

export const FormControl = ({ input, meta: { touched, error }, children }) => {
  const hasError = touched && error;

  return (
    <div
      className={classes.formControl + " " + (hasError ? classes.error : "")}
    >
      <div>{children}</div>
      {hasError && <span>{error}</span>}
    </div>
  );
};

export const Textarea = (props) => {
  const { input, meta, child, ...restProps } = props;
  return (
    <div>
      <FormControl {...props}>
        <textarea {...input} {...restProps} />
      </FormControl>
    </div>
  );
};

export const TextArea = (props) => {
  const { input, meta, child, ...restProps } = props;
  return (
    <div>
      <FormControl {...props}>
        <TextField variant="outlined"  {...input} {...restProps} />
      </FormControl>
    </div>
  );
};

export const Input = (props) => {
  const { input, meta, child, ...restProps } = props;
  return (
    <div>
      <FormControl {...props}>
        <input {...input} {...restProps} />
      </FormControl>
    </div>
  );
};

export const createField = (
  placeholder,
  name,
  validators,
  component,
  props = {},
  text = ""
) => (
  <div>
    <Field
      placeholder={placeholder}
      name={name}
      validate={validators}
      component={component}
      {...props}
    />
    {text}
  </div>
);
